@@ -2,10 +2,11 @@
 
 crc32.h
 
-Author: Tatu Ylonen <ylo@cs.hut.fi>
+Author: Tatu Ylonen <ylo@ssh.fi>
 
 Copyright (c) 1992 Tatu Ylonen, Espoo, Finland
-                   All rights reserved
+Copyright (c) 1995-1999 SSH Communications Security Oy, Espoo, Finland
+                        All rights reserved
 
 Created: Tue Feb 11 14:37:27 1992 ylo
 
@@ -14,14 +15,17 @@ Functions for computing 32-bit CRC.
 */
 
 /*
- * $Id: crc32.h,v 1.1.1.1 1996/02/18 21:38:11 ylo Exp $
+ * $Id: crc32.h,v 1.2 1999/11/17 17:04:43 tri Exp $
  * $Log: crc32.h,v $
- * Revision 1.1.1.1  1996/02/18  21:38:11  ylo
- * 	Imported ssh-1.2.13.
+ * Revision 1.2  1999/11/17 17:04:43  tri
+ * 	Fixed copyright notices.
+ *
+ * Revision 1.1.1.1  1996/02/18 21:38:11  ylo
+ *      Imported ssh-1.2.13.
  *
  * Revision 1.2  1995/07/13  01:21:45  ylo
- * 	Removed "Last modified" header.
- * 	Added cvs log.
+ *      Removed "Last modified" header.
+ *      Added cvs log.
  *
  * $Endlog$
  */
