@@ -2,11 +2,13 @@
 
 sshsia.h
 
+Author: Tom Woodburn <woodburn@zk3.dec.com>
+
 Helper functions for using the SIA (Security Integration Architecture)
 functions of Tru64 UNIX.
 
+Copyright (c) 1999 COMPAQ Computer Corp, all rights reserved
 Copyright (c) 1999 SSH Communications Security Oy, Espoo, Finland
-                   and Compaq Computer Corporation
 
 */
 
@@ -15,11 +17,11 @@ Copyright (c) 1999 SSH Communications Security Oy, Espoo, Finland
 
 #include <sia.h>
 
-void initialize_sia(int ac, char **av);
-void get_sia_args(int *ac, char ***av);
-int my_sia_validate_user(sia_collect_func_t *collect, int argc, char *argv[],
+void ssh_sia_initialize(int ac, char **av);
+void ssh_sia_get_args(int *ac, char ***av);
+int ssh_sia_validate_user(sia_collect_func_t *collect, int argc, char *argv[],
                          char *hostname, char *username, char *tty,
                          int colinput, char *gssapi, char *passphrase);
-int sia_no_password(const char *server_user);
+int ssh_sia_no_password(const char *server_user);
 
 #endif /* SSHSIA_H */
